@@ -13,13 +13,25 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.utils.translation import ugettext_lazy as _
 from horizon import exceptions
 from horizon import tabs
 
 from blazar_dashboard.api import client
 
+RESERVATION_GENERALS = (
+    'id',
+    'lease_id',
+    'resource_id',
+    'resource_type',
+    'status',
+    'missing_resources',
+    'resources_changed',
+    'created_at',
+    'updated_at'
+)
+
 
 class OverviewTab(tabs.Tab):
     name = _("Overview")
@@ -35,7 +47,8 @@ class OverviewTab(tabs.Tab):
             msg = _('Unable to retrieve lease details.')
             exceptions.handle(request, msg, redirect=redirect)
 
-        return {'lease': lease}
+        return {'lease': lease,
+                'reservation_generals': RESERVATION_GENERALS}
 
 
 class LeaseDetailTabs(tabs.TabGroup):
